@@ -1,9 +1,9 @@
 #' @title Create command declaring FREESURFER_HOME
 #' @description Finds the Freesurfer from system environment or \code{getOption("freesurfer.path")}
 #' for location of Freesurfer functions
-#' @param add_bin Should \code{bin} be added to the freesurfer path? 
-#' All executables are assumed to be in \code{FREESURFER_HOME/}.  If not, and 
-#' \code{add_bin = FALSE}, they will be assumed to be in \code{FreesurferDIR/}.
+#' @param bin_app Should \code{bin} be added to the freesurfer path? 
+#' All executables are assumed to be in \code{FREESURFER_HOME/bin/}.  If not, and 
+#' \code{bin_app = ""}, they will be assumed to be in \code{FREESURFER_HOME/}.
 #' @note This will use \code{Sys.getenv("FREESURFER_HOME")} before \code{getOption("freesurfer.path")}.
 #' If the directory is not found for Freesurfer in \code{Sys.getenv("FreesurferDIR")} and 
 #' \code{getOption("freesurfer.path")}, it will try the default directory \code{/usr/local/freesurfer}.
@@ -13,12 +13,11 @@
 #' if (have_fs()) {
 #' get_fs()
 #' }
-get_fs = function(add_bin = TRUE){
+get_fs = function(bin_app = c("bin", "mni/bin", "")) {
   cmd = NULL
-
-   
   freesurferdir = Sys.getenv("FREESURFER_HOME")
   if (freesurferdir == "") {
+    bin_app = match.arg(bin_app)
     freesurferdir = getOption("freesurfer.path")
     ## Will try a default directory (/usr/local/freesurfer) if nothing else
     if (is.null(freesurferdir)) {
@@ -33,20 +32,50 @@ get_fs = function(add_bin = TRUE){
         }
       }
     }
-    bin = "bin"
-    bin_app = paste0(bin, "/")
-    if (!add_bin) {
-      bin_app = bin = ""
-    }
+    # bin = "bin"
+    bin_app = paste0(bin_app, "/")
+    # if (!add_bin) {
+    #   bin_app = bin = ""
+    # }
     # FSF_OUTPUT_FORMAT
     freesurferout = get_fs_output()
-    shfile = file.path(freesurferdir, "SetUpFreeSurfer.sh")
-    cmd <- paste0("FREESURFER_HOME=", shQuote(freesurferdir), "; ", 
-                  ifelse(file.exists(shfile), 
-                         paste0('sh ', shQuote(shfile)), ";"),
+    # lic_file = file.path(freesurferdir, "license.txt")
+    # if (!file.exists(lic_file)) {
+    #   try_lic_file = file.path(freesurferdir, "LICENSE")
+    #   if (file.exists(try_lic_file)) {
+    #     file.copy(from = try_lic_file, to = lic_file, overwrite = FALSE)
+    #   }
+    # }
+    cmd = NULL
+    ###########################################
+    # Need to fix PERL startup 
+    ###########################################    
+    if (grepl("mni", bin_app)) {
+      mni_dir = file.path(freesurferdir, "mni")
+      start_up = list.files(pattern = "MNI[.]pm", 
+                            path = mni_dir, 
+                            full.names = TRUE, recursive = TRUE)
+      if (length(start_up) > 1) {
+        start_up = start_up[1]
+        warning("First MNI.pm file found used");
+      }
+      if (length(start_up) == 0) {
+        warning("MNI startup file not found, trying MNI function anyway ")
+        cmd = NULL
+      } else {
+        start_up = dirname(start_up)
+        cmd = paste0("export PERL5LIB=$PERL5LIB:", start_up, " ; ")
+      }
+    }
+    
+    # shfile = file.path(freesurferdir, "SetUpFreeSurfer.sh")
+    cmd <- paste0(cmd, 
+                  "export FREESURFER_HOME=", shQuote(freesurferdir), "; ", 
+                  # ifelse(file.exists(shfile), 
+                  #        paste0('sh ', shQuote(shfile), "; "), ""),
                   "FSF_OUTPUT_FORMAT=", freesurferout, "; export FSF_OUTPUT_FORMAT; ", 
                   paste0("${FREESURFER_HOME}/", bin_app)
-                  )
+    )
   } 
   if (is.null(freesurferdir)) stop("Can't find Freesurfer")
   if (freesurferdir %in% "") stop("Can't find Freesurfer")
@@ -55,7 +84,8 @@ get_fs = function(add_bin = TRUE){
 
 
 #' @title Get Freesurfer's Directory 
-#' @description Finds the FreesurferDIR from system environment or \code{getOption("freesurfer.path")}
+#' @description Finds the FREESURFER_HOME from system environment or 
+#' \code{getOption("freesurfer.path")}
 #' for location of Freesurfer fuctions and returns it
 #' @return Character path
 #' @aliases freesurfer_dir
@@ -67,7 +97,7 @@ get_fs = function(add_bin = TRUE){
 #'  fs_dir()
 #' }
 freesurferdir = function(){
-  freesurferdir = Sys.getenv("FreesurferDIR")
+  freesurferdir = Sys.getenv("FREESURFER_HOME")
   if (freesurferdir == "") {
     x = get_fs()
     freesurferdir = getOption("freesurfer.path")
@@ -142,4 +172,60 @@ fs_imgext = function(){
                "nii.gz" = ".nii.gz", 
                "nii" = ".nii")
   return(ext)
-}
\ No newline at end of file
+}
+
+
+#' @title Determine Freesurfer Subjects Directory
+#' @description Finds the SUBJECTS_DIR from system environment or 
+#' \code{getOption("fs.subj_dir")} for subjects dir
+#' @return SUBJECTS_DIR, such as \code{${FREESURFER_HOME}/subjects}
+#' 
+#' @export
+#' @examples
+#' if (have_fs()) {
+#'    fs_subj_dir()
+#' }
+fs_subj_dir  = function(){
+  fs_out = Sys.getenv("SUBJECTS_DIR")
+  if (fs_out == "") {
+    fs_out = getOption("fs.subj_dir")
+  }
+  if (is.null(fs_out)) {
+    warning("SUBJECTS_DIR not set, setting to ", 
+            paste0("file.path(set_fs_subj_dir(), 'subjects')"))
+    res = suppressWarnings(try(
+      set_fs_subj_dir(), 
+      silent = TRUE)
+    )
+    if (inherits(res, "try-error")) {
+      fs_out = NA
+    } else {
+      fs_out = res
+    }
+    
+    # fs_out = file.path(fs_dir(), "subjects")
+  }
+  if (!is.na(fs_out)) {
+    if (fs_out == "") {
+      fs_out = NA
+    }
+  }
+  return(fs_out)
+}
+
+#' @title Set Freesurfer Subjects Directory
+#' @description Sets the SUBJECTS_DIR variable in the system environment or 
+#' \code{options("fs.subj_dir" = x)} 
+#' @param x path to SUBJECTS_DIR defaults to \code{file.path(fs_dir(), "subjects")}
+#' @return NULL
+#' 
+#' @export
+set_fs_subj_dir  = function(x = file.path(fs_dir(), "subjects")){
+  if (!file.exists(x)) {
+    stop("Path to set subj_dir does not exist, erroring out!")
+  }
+  options("fs.subj_dir" = x)
+  Sys.setenv("SUBJECTS_DIR" = x)
+  return(x)
+}
+
